@@ -122,7 +122,14 @@ GladePropertyLabel relation_names_table[] = {
   { "label-for", N_("Label For") },
   { "labelled-by", N_("Labelled By") },
   { "member-of", N_("Member Of") },
-  { "node-child-of", N_("Node Child Of") }
+  { "node-child-of", N_("Node Child Of") },
+  { "flows-to", N_("Flows To") },
+  { "flows-from", N_("Flows From") },
+  { "subwindow-of", N_("Subwindow Of") },
+  { "embeds", N_("Embeds") },
+  { "embedded-by", N_("Embedded By") },
+  { "popup-for", N_("Popup For") },
+  { "parent-window-of", N_("Parent Window Of") }
 };
 
 /* This returns the translated relation name. We hardcode some strings here so
@@ -629,7 +636,7 @@ glade_atk_create_property_page	(GtkNotebook *notebook)
   property_add_string (GladeATKName, _("Name:"),
 		       _("The name of the widget to pass to assistive technologies"));
   property_add_text (GladeATKDescription, _("Description:"),
-		       _("The description of the widget to pass to assistive technologies"), 2);
+		       _("The description of the widget to pass to assistive technologies"), 4);
 #if 0
   property_add_text (GladeATKTableCaption, _("Table Caption:"),
 		       _("The table caption to pass to assistive technologies"), 2);
@@ -1019,19 +1026,39 @@ glade_atk_set_properties	(GtkWidget * widget,
 
 static void
 save_atk_property (GbWidgetGetArgData * data, GString *buffer, gint indent,
-		   const gchar * tag_name, const gchar * tag_value,
-		   gboolean translatable)
+		   const gchar * tag_name, const gchar * tag_value)
 {
+  gboolean translatable, context;
+  gchar *comments;
+
   if (tag_value == NULL)
     return;
 
+  glade_util_get_translation_properties (data->widget, tag_name, &translatable,
+					 &comments, &context);
+
   save_buffer_add_indent (buffer, indent);
   g_string_append (buffer, "<atkproperty name=\"");
   save_buffer_add_string (buffer, tag_name);
+  g_string_append_c (buffer, '"');
+
   if (translatable)
-    g_string_append (buffer, "\" translatable=\"yes\">");
-  else
-    g_string_append (buffer, "\">");
+    {
+      g_string_append (buffer, " translatable=\"yes\"");
+
+      if (context)
+	g_string_append (buffer, " context=\"yes\"");
+
+      if (comments && *comments)
+	{
+	  g_string_append (buffer, " comments=\"");
+	  save_buffer_add_string (buffer, comments);
+	  g_string_append_c (buffer, '"');
+	}
+    }
+
+  g_string_append_c (buffer, '>');
+
   save_buffer_add_string (buffer, tag_value);
   g_string_append (buffer, "</atkproperty>\n");
 
@@ -1053,13 +1080,12 @@ glade_atk_save_atk_properties	(GtkWidget * widget,
      by the user, and are not empty. There may be default settings. */
   name = atk_object_get_name (atko);
   if (name && *name && g_object_get_data (G_OBJECT (atko), GladeATKName))
-    save_atk_property (data, buffer, indent, GladeATKName, name, TRUE);
+    save_atk_property (data, buffer, indent, GladeATKName, name);
 
   description = atk_object_get_description (atko);
   if (description && *description
       && g_object_get_data (G_OBJECT (atko), GladeATKDescription))
-    save_atk_property (data, buffer, indent, GladeATKDescription, description,
-		       TRUE);
+    save_atk_property (data, buffer, indent, GladeATKDescription, description);
 
 #if 0
   if (GTK_IS_TREE_VIEW (widget))
@@ -1072,7 +1098,7 @@ glade_atk_save_atk_properties	(GtkWidget * widget,
       if (table_caption && *table_caption
 	  && g_object_get_data (G_OBJECT (atko), GladeATKTableCaption))
 	save_atk_property (data, buffer, indent, GladeATKTableCaption,
-			   table_caption, TRUE);
+			   table_caption);
     }
 #endif
 }
@@ -1208,11 +1234,21 @@ glade_atk_load_atk_properties	(GtkWidget * widget,
 	  /* Set a flag to indicate the name has been set explicitly. */
 	  g_object_set_data (G_OBJECT (atko), GladeATKName, "T");
 	  atk_object_set_name (atko, prop->value);
+
+	  glade_util_set_translation_properties (widget, GladeATKName,
+						 prop->translatable,
+						 prop->translator_comments,
+						 prop->context_prefix);
 	}
       else if (!strcmp (prop->name, GladeATKDescription))
 	{
 	  g_object_set_data (G_OBJECT (atko), GladeATKDescription, "T");
 	  atk_object_set_description (atko, prop->value);
+
+	  glade_util_set_translation_properties (widget, GladeATKDescription,
+						 prop->translatable,
+						 prop->translator_comments,
+						 prop->context_prefix);
 	}
 #if 0
       else if (GTK_IS_TREE_VIEW (widget)
@@ -1222,6 +1258,11 @@ glade_atk_load_atk_properties	(GtkWidget * widget,
 	  g_object_set (G_OBJECT (atko),
 			"AtkObject::accessible-table-caption", prop->value,
 			NULL);
+
+	  glade_util_set_translation_properties (widget, GladeATKTableCaption,
+						 prop->translatable,
+						 prop->translator_comments,
+						 prop->context_prefix);
 	}
 #endif
     }
@@ -1271,7 +1312,7 @@ glade_atk_load_relations	(GtkWidget * widget,
   for (i = 0; i < info->n_relations; i++)
     {
       GladeAtkRelationInfo *relation = &info->relations[i];
-      AtkRelationType relationship;
+      AtkRelationType relationship = ATK_RELATION_NULL;
       GtkWidget *target = NULL;
 
       /* Convert the type string to an integer. */
@@ -1357,6 +1398,25 @@ glade_atk_source_add		(GString *buffer,
 }
 
 
+void
+glade_atk_source_add_translator_comments (GString *buffer,
+					  gboolean translatable,
+					  const gchar *comments)
+{
+  /* If the property isn't being translated we don't bother outputting the
+     translator comments. */
+  if (!translatable || !comments || comments[0] == '\0')
+    return;
+
+  /* We simply output it in a C comment.
+     FIXME: If the comments contain an end of comment marker it won't
+     compile. */
+  g_string_append (buffer, "  /* ");
+  g_string_append (buffer, comments);
+  g_string_append (buffer, " */\n");
+}
+
+
 static void
 glade_atk_write_atk_properties_source 	(GtkWidget * widget,
 					 AtkObject * atko,
@@ -1364,6 +1424,8 @@ glade_atk_write_atk_properties_source 	(GtkWidget * widget,
 					 GString   * buffer)
 {
   const char *name, *description;
+  gboolean translatable, context;
+  gchar *comments;
 
   /* We only generate code for setting the name, description and caption if
      they are set explicitly by the user, and are not empty. There may be
@@ -1371,18 +1433,30 @@ glade_atk_write_atk_properties_source 	(GtkWidget * widget,
   name = atk_object_get_name (atko);
   if (name && *name && g_object_get_data (G_OBJECT (atko), GladeATKName))
     {
+      glade_util_get_translation_properties (widget, GladeATKName,
+					     &translatable,
+					     &comments, &context);
+      glade_atk_source_add_translator_comments (buffer, translatable,
+						comments);
+
       glade_atk_source_add (buffer,
 			    "  atk_object_set_name (atko, %s);\n",
-			    source_make_string (name, data->use_gettext));
+			    source_make_string_full (name, data->use_gettext && translatable, context));
     }
 
   description = atk_object_get_description (atko);
   if (description && *description
       && g_object_get_data (G_OBJECT (atko), GladeATKDescription))
     {
+      glade_util_get_translation_properties (widget, GladeATKDescription,
+					     &translatable,
+					     &comments, &context);
+      glade_atk_source_add_translator_comments (buffer, translatable,
+						comments);
+
       glade_atk_source_add (buffer,
 			    "  atk_object_set_description (atko, %s);\n",
-			    source_make_string (description, data->use_gettext));
+			    source_make_string_full (description, data->use_gettext && translatable, context));
     }
 
 #if 0
@@ -1396,11 +1470,16 @@ glade_atk_write_atk_properties_source 	(GtkWidget * widget,
       if (table_caption && *table_caption
 	  && g_object_get_data (G_OBJECT (atko), GladeATKTableCaption))
 	{
+	  glade_util_get_translation_properties (widget, GladeATKTableCaption,
+						 &translatable,
+						 &comments, &context);
+	  glade_atk_source_add_translator_comments (buffer, translatable,
+						    comments);
+
 	  glade_atk_source_add (buffer,
-				"  g_object_set (G_OBJECT (atko),\n"
-				"                \"AtkObject::accessible-table-caption\", %s,\n"
+				"  g_object_set (G_OBJECT (atko), \"AtkObject::accessible-table-caption\", %s,\n"
 				"                NULL);\n",
-			    source_make_string (table_caption, data->use_gettext));
+			    source_make_string_full (table_caption, data->use_gettext && translatable, context));
 
 	}
     }
